@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_qldb import QLDBClient
 
-    session = boto3.Session()
-
     client: QLDBClient = boto3.client("qldb")
-    session_client: QLDBClient = session.client("qldb")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
