@@ -3,9 +3,11 @@ Main interface for qldb service type definitions.
 
 Usage::
 
-    from mypy_boto3.qldb.type_defs import JournalKinesisStreamDescriptionTypeDef
+    ```python
+    from mypy_boto3_qldb.type_defs import JournalKinesisStreamDescriptionTypeDef
 
     data: JournalKinesisStreamDescriptionTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
